(function() {
  const currentVersion = '1.0.0';
  const versionCheckUrl = 'https://radiomv.com/apps/mac/latest-version.txt';
  const downloadUrl = 'https://radiomv.com/apps/mac/';

  fetch(versionCheckUrl)
    .then(response => response.text())
    .then(latestVersion => {
      if (compareVersions(latestVersion.trim(), currentVersion)) {
        promptUpdate(downloadUrl);
      }
    })
    .catch(error => {
      console.error('Error checking for app updates:', error);
    });

  function compareVersions(latest, current) {
    const latestParts = latest.split('.').map(Number);
    const currentParts = current.split('.').map(Number);
    for (let i = 0; i < latestParts.length; i++) {
      if (latestParts[i] > (currentParts[i] || 0)) {
        return true;
      } else if (latestParts[i] < (currentParts[i] || 0)) {
        return false;
      }
    }
    return false;
  }

  function promptUpdate(downloadUrl) {
    const updateDiv = document.createElement('div');
    updateDiv.style.position = 'fixed';
    updateDiv.style.bottom = '20px';
    updateDiv.style.right = '20px';
    updateDiv.style.padding = '15px';
    updateDiv.style.backgroundColor = '#f1c40f';
    updateDiv.style.color = '#000';
    updateDiv.style.border = '1px solid #e1b12c';
    updateDiv.style.borderRadius = '5px';
    updateDiv.style.zIndex = '10000';
    updateDiv.style.fontFamily = 'Arial, sans-serif';
    updateDiv.style.boxShadow = '0 0 10px rgba(0,0,0,0.2)';
    updateDiv.innerHTML = `
      <strong>Update Available!</strong><br>
      A new version of RadioMv Player is available.
      <button id="update-button" style="
        margin-top: 10px;
        padding: 5px 10px;
        background-color: #27ae60;
        color: #fff;
        border: none;
        border-radius: 3px;
        cursor: pointer;
      ">Download New</button>
      <button id="close-button" style="
        margin-top: 10px;
        margin-left: 5px;
        padding: 5px 10px;
        background-color: #c0392b;
        color: #fff;
        border: none;
        border-radius: 3px;
        cursor: pointer;
      ">Dismiss</button>
    `;
    document.body.appendChild(updateDiv);
    document.getElementById('update-button').addEventListener('click', () => {
      require('electron').shell.openExternal(downloadUrl);
      document.body.removeChild(updateDiv);
    });
    document.getElementById('close-button').addEventListener('click', () => {
      document.body.removeChild(updateDiv);
    });
  }

  // Improved last visited URL functionality
  document.addEventListener('DOMContentLoaded', function() {
    const defaultUrl = 'https://player.radiomv.com/';
    const lastVisitedUrl = localStorage.getItem('lastVisitedUrl') || defaultUrl;

    if (window.location.href !== lastVisitedUrl) {
      window.location.href = lastVisitedUrl;
    }
  });

  // Save URL on page changes
  window.addEventListener('beforeunload', function() {
    localStorage.setItem('lastVisitedUrl', window.location.href);
  });

  // Additional listener for single-page app navigation
  const observer = new MutationObserver(function(mutations) {
    localStorage.setItem('lastVisitedUrl', window.location.href);
  });

  // Start observing URL changes
  observer.observe(document.documentElement, {
    subtree: true,
    childList: true
  });
})();
